"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const Connector = ({ id, previousMatchPosition, currentMatchPosition, calculatedStyle, isHighlighted, isActive, offsetY = 0, }) => {
    const { boxHeight, connectorColor, roundHeader, roundSeparatorWidth, lineInfo, horizontalOffset, connectorColorHighlight, connectorColorActive, connectorLineThickness, width, } = calculatedStyle;
    const halfConnectorLineThickness = Math.floor(connectorLineThickness / 2);
    const halfBoxHeight = Math.floor(boxHeight / 2);
    const halfRoundSeperatorWidth = Math.floor(roundSeparatorWidth / 2);
    const middlePointOfMatchComponent = halfBoxHeight - halfConnectorLineThickness;
    const getCoords = () => {
        const previousMatch = previousMatchPosition;
        const startPointX = previousMatch.x + width + horizontalOffset + lineInfo.separation;
        const startPointY = previousMatch.y +
            lineInfo.homeVisitorSpread +
            middlePointOfMatchComponent +
            (roundHeader.isShown ? roundHeader.height + roundHeader.marginBottom : 0);
        const halfHorizontalWidth = currentMatchPosition.x -
            halfRoundSeperatorWidth -
            horizontalOffset -
            startPointX;
        const verticalHeight = currentMatchPosition.y - previousMatch.y + offsetY;
        const isPreviousMatchOnSameYLevel = Math.abs(currentMatchPosition.y - previousMatch.y) < 1;
        return {
            startPointX,
            startPointY,
            halfHorizontalWidth,
            verticalHeight,
            isConnectorStraight: isPreviousMatchOnSameYLevel,
        };
    };
    function getColor() {
        if (isHighlighted) {
            return connectorColorHighlight;
        }
        if (isActive) {
            return connectorColorActive;
        }
        return connectorColor;
    }
    const { startPointX, startPointY, isConnectorStraight, halfHorizontalWidth, verticalHeight, } = getCoords();
    if (isConnectorStraight) {
        return (react_1.default.createElement("g", { id: `connector-${id}` },
            react_1.default.createElement("rect", { x: startPointX, y: startPointY, height: connectorLineThickness, width: halfHorizontalWidth * 2, fill: getColor() })));
    }
    return (react_1.default.createElement("g", { id: `connector-${id}` },
        react_1.default.createElement("rect", { x: startPointX, y: startPointY, height: connectorLineThickness, width: halfHorizontalWidth, fill: getColor() }),
        react_1.default.createElement("rect", { x: startPointX + halfHorizontalWidth - halfConnectorLineThickness, y: startPointY, width: connectorLineThickness, height: verticalHeight, fill: getColor() }),
        react_1.default.createElement("rect", { x: startPointX + halfHorizontalWidth - halfConnectorLineThickness, y: startPointY + verticalHeight, height: connectorLineThickness, width: halfHorizontalWidth + halfConnectorLineThickness, fill: getColor() })));
};
exports.default = Connector;
//# sourceMappingURL=connector.js.map