"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useIsCollapsed = exports.useItemHighlightContext = exports.useItemContext = exports.itemContext = void 0;
const react_1 = require("react");
const helpers_1 = require("./helpers");
const treeToRenderAdapter_1 = require("./treeToRenderAdapter");
const initialState = {
    renderData: [],
    activeItemIds: [],
    hoveredItems: [],
    collapsedItemIds: [],
};
const store = react_1.createContext({
    state: {
        renderData: [[]],
        activeItemIds: [],
        hoveredItems: [],
        collapsedItemIds: [],
    },
    dispatch: () => { },
});
exports.itemContext = store;
const useItemContext = (initialTree, initialActiveItemIds) => {
    const renderMatrix = treeToRenderAdapter_1.generateRenderData(initialTree);
    const path = processActiveItems(renderMatrix, initialActiveItemIds);
    const [state, dispatch] = react_1.useReducer((previousState, action) => {
        var _a, _b;
        switch (action.type) {
            case 'TOGGLE_COLLAPSE': {
                const { currentItem } = (_a = action.payload) !== null && _a !== void 0 ? _a : {};
                const isAlreadyCollapsed = previousState.collapsedItemIds.includes(currentItem.uniqueId);
                const newCollapsedItems = isAlreadyCollapsed
                    ? previousState.collapsedItemIds.filter(itemId => itemId !== currentItem.uniqueId)
                    : [...previousState.collapsedItemIds, currentItem.uniqueId];
                const newRenderData = treeToRenderAdapter_1.generateRenderData(initialTree, newCollapsedItems);
                return Object.assign(Object.assign({}, previousState), { collapsedItemIds: newCollapsedItems, renderData: newRenderData });
            }
            case 'SET_HOVERED': {
                const { currentHoveredItem, hoveredColumnIndex: columnIndex, } = (_b = action.payload) !== null && _b !== void 0 ? _b : {};
                const newPath = currentHoveredItem
                    ? helpers_1.findPathFromItem([currentHoveredItem.uniqueId], currentHoveredItem.parentUniqueId, previousState.renderData.slice(0, Math.max(columnIndex, 0)))
                    : [];
                return Object.assign(Object.assign({}, previousState), { hoveredItems: newPath });
            }
            case 'SET_BLURRED': {
                return Object.assign(Object.assign({}, previousState), { hoveredItems: [] });
            }
            case 'UPDATE_TREE': {
                const { tree, activeItemIds } = action.payload;
                const newRenderMatrix = treeToRenderAdapter_1.generateRenderData(tree, previousState.collapsedItemIds);
                const newActiveItemsId = processActiveItems(newRenderMatrix, activeItemIds);
                return Object.assign(Object.assign({}, previousState), { renderData: newRenderMatrix, activeItemIds: newActiveItemsId });
            }
            default: {
                return previousState;
            }
        }
    }, Object.assign(Object.assign({}, initialState), { renderData: renderMatrix, activeItemIds: path }));
    react_1.useEffect(() => {
        dispatch({
            type: 'UPDATE_TREE',
            payload: { tree: initialTree, activeItemIds: initialActiveItemIds },
        });
    }, [initialTree, initialActiveItemIds]);
    return [state, dispatch];
};
exports.useItemContext = useItemContext;
const useItemHighlightContext = ({ currentItem, }) => {
    const { state: { hoveredItems, activeItemIds }, } = react_1.useContext(exports.itemContext);
    const highlighted = hoveredItems.some(itemId => itemId === currentItem.uniqueId);
    const isActive = activeItemIds.some(itemId => itemId === currentItem.uniqueId);
    return { isHighlighted: highlighted, isActive };
};
exports.useItemHighlightContext = useItemHighlightContext;
const useIsCollapsed = ({ currentItem, }) => {
    const { state: { collapsedItemIds }, } = react_1.useContext(exports.itemContext);
    const isCollapsed = collapsedItemIds.some(collapsedItemId => collapsedItemId === currentItem.uniqueId);
    return isCollapsed;
};
exports.useIsCollapsed = useIsCollapsed;
function processActiveItems(renderMatrix, activeItemIds) {
    const path = activeItemIds.length > 0
        ? activeItemIds.reduce((acc, activeItemUniqueId) => {
            const { item, column } = helpers_1.findItemFromRenderMatrix(renderMatrix, activeItemUniqueId);
            if (item == null) {
                return acc;
            }
            const newIds = helpers_1.findPathFromItem([item.uniqueId], item.parentUniqueId, renderMatrix.slice(0, Math.max(column, 0)));
            return [...acc, ...newIds];
        }, [])
        : [];
    return path;
}
//# sourceMappingURL=item-context.js.map